"""Function to ease connection to a postgres database"""

import logging
from argparse import ArgumentParser, Namespace
from typing import Optional

from psycopg2 import connect

_logger = logging.getLogger(__name__)


def postgres_connect_parser(
    parser: ArgumentParser,
    prefix: str = "",
    database_prefix: str = "",
    default_user: Optional[str] = None,
    default_password: Optional[str] = None,
    default_database: Optional[str] = None,
):
    """Create a parser for a postgres connection"""
    argument_prefix = f"{prefix}-" if prefix else ""
    parser.add_argument(
        f"--{database_prefix + '-' if database_prefix else ''}database",
        help="the database name",
        default=default_database,
    )
    parser.add_argument(
        f"--{argument_prefix}user",
        help="user name used to authenticate",
        default=default_user,
    )
    parser.add_argument(
        f"--{argument_prefix}password",
        help="password used to authenticate",
        default=default_password,
    )
    parser.add_argument(
        f"--{argument_prefix}host",
        help="database host address (defaults to UNIX socket if not provided)",
    )
    parser.add_argument(
        f"--{argument_prefix}port",
        help="connection port number (defaults to 5432 if not provided)",
        type=int,
    )


def postgres_connect_args(
    namespace: Namespace, prefix: str = "", database_prefix: str = ""
):
    connect_args = {}
    argument_prefix = f"{prefix}_" if prefix else ""
    for argument in ("user", "password", "host", "port"):
        connect_args[argument] = getattr(namespace, f"{argument_prefix}{argument}")
    connect_args["database"] = getattr(
        namespace, f"{database_prefix + '-' if database_prefix else ''}database"
    )
    return connect_args


def postgres_apply(namespace: Namespace, prefix: str = ""):
    """Use postgres_connect_parser result to create a postgres connection
    :return: a psycopg2 connection
    """
    return connect(**postgres_connect_args(namespace, prefix))


def host_from_dsn(dsn: str) -> Optional[str]:
    connection = connect(dsn)
    return connection.get_dsn_parameters()["host"]
