"""Global Version Number"""

from json import loads

try:
    # python 3.8+
    from importlib.metadata import PackageNotFoundError, distribution
except ModuleNotFoundError:
    from importlib_metadata import (  # type: ignore[import,no-redef,assignment]
        PackageNotFoundError,
        distribution,
    )

# This is maintained by bump-my-version.
# The value is used when odoo scripts is not installed, or in editable installation.
# In normal install, use the version of the package.
__version__ = "24.2.0"
try:
    # When using an editable installation, the number would be off
    distrib = distribution("odoo-scripts")
    text = distrib.read_text("direct_url.json")
    if text is not None:
        json = loads(text)
        if json.get("dir_info", {}).get("editable", False):
            split = __version__.split(".")
            __version__ = ".".join(split[:2] + [f"{int(split[2]) + 1}.dev"])
        else:
            __version__ = distrib.version
except PackageNotFoundError:
    pass
